@@ -1935,7 +1935,7 @@ def test_task_desc_confirm_unknown_message_prompts_menu():
     state_value = asyncio.run(scenario())
 
     assert state_value == bot.TaskDescriptionStates.waiting_confirm.state
-    assert message.calls and "请使用菜单中的按钮" in message.calls[-1][0]
+    assert message.calls and ("请使用菜单中的按钮" in message.calls[-1][0] or "当前处于确认阶段" in message.calls[-1][0])
     assert isinstance(message.calls[-1][2], ReplyKeyboardMarkup)
 
 
@@ -2306,3 +2306,204 @@ def test_task_list_outputs_detail_buttons(monkeypatch, tmp_path: Path):
     ]
     assert detail_texts, "应包含跳转详情的按钮"
     assert "🛠️" in detail_texts[0], "详情按钮文本应展示类型图标"
+
+
+def test_task_desc_confirm_numeric_input_1_confirms(monkeypatch):
+    """测试输入数字"1"应触发确认更新操作"""
+    message = DummyMessage()
+    state, _storage = make_state(message)
+
+    update_calls = []
+
+    async def fake_update_task(task_id: str, *, actor: str, **kwargs) -> TaskRecord:
+        update_calls.append((task_id, actor, kwargs.get("description")))
+        return _make_task(task_id=task_id, title="任务", status="research")
+
+    monkeypatch.setattr(bot.TASK_SERVICE, "update_task", fake_update_task)
+
+    async def fake_render_task_detail(task_id: str):
+        return "任务详情", None
+
+    monkeypatch.setattr(bot, "_render_task_detail", fake_render_task_detail)
+
+    async def scenario() -> str | None:
+        message.text = "1"  # 输入数字1，应该对应第一个选项"确认更新"
+        await state.update_data(
+            task_id="TASK_EDIT",
+            new_description="新的描述内容",
+            actor="Tester#1",
+            current_description="旧描述",
+        )
+        await state.set_state(bot.TaskDescriptionStates.waiting_confirm)
+        await bot.on_task_desc_confirm_stage_text(message, state)
+        return await state.get_state()
+
+    state_value = asyncio.run(scenario())
+
+    assert state_value is None, "确认后应清空状态"
+    assert update_calls == [("TASK_EDIT", "Tester#1", "新的描述内容")], "应调用更新任务"
+    assert message.calls and "任务描述已更新" in message.calls[0][0]
+
+
+def test_task_desc_confirm_numeric_input_2_retries(monkeypatch):
+    """测试输入数字"2"应触发重新输入操作"""
+    message = DummyMessage()
+    state, _storage = make_state(message)
+
+    task = _make_task(task_id="TASK_EDIT", title="描述任务", status="research")
+    task.description = "原始描述"
+
+    async def fake_get_task(task_id: str):
+        assert task_id == "TASK_EDIT"
+        return task
+
+    monkeypatch.setattr(bot.TASK_SERVICE, "get_task", fake_get_task)
+
+    async def scenario() -> tuple[str | None, dict]:
+        message.text = "2"  # 输入数字2，应该对应第二个选项"重新输入"
+        await state.update_data(
+            task_id="TASK_EDIT",
+            new_description="草稿描述",
+            actor="Tester#1",
+            current_description="旧描述",
+        )
+        await state.set_state(bot.TaskDescriptionStates.waiting_confirm)
+        await bot.on_task_desc_confirm_stage_text(message, state)
+        return await state.get_state(), await state.get_data()
+
+    state_value, data = asyncio.run(scenario())
+
+    assert state_value == bot.TaskDescriptionStates.waiting_content.state, "应回到输入状态"
+    assert data.get("new_description") is None, "应清空草稿描述"
+    assert len(message.calls) >= 4
+    first_text, _, first_markup, _ = message.calls[0]
+    assert "已回到描述输入阶段" in first_text
+    assert isinstance(first_markup, ReplyKeyboardMarkup)
+
+
+def test_task_desc_confirm_numeric_input_3_cancels():
+    """测试输入数字"3"应触发取消操作"""
+    message = DummyMessage()
+    state, _storage = make_state(message)
+
+    async def scenario() -> str | None:
+        message.text = "3"  # 输入数字3，应该对应第三个选项"取消"
+        await state.update_data(
+            task_id="TASK_EDIT",
+            new_description="草稿描述",
+            actor="Tester#1",
+            current_description="旧描述",
+        )
+        await state.set_state(bot.TaskDescriptionStates.waiting_confirm)
+        await bot.on_task_desc_confirm_stage_text(message, state)
+        return await state.get_state()
+
+    state_value = asyncio.run(scenario())
+
+    assert state_value is None, "取消后应清空状态"
+    assert message.calls and "已取消编辑任务描述" in message.calls[0][0]
+    _, _, markup, _ = message.calls[0]
+    assert isinstance(markup, ReplyKeyboardMarkup), "应显示主菜单键盘"
+
+
+def test_task_desc_confirm_numeric_input_with_prefix():
+    """测试输入带前缀的按钮文本（如"1. ✅ 确认更新"）也能正确识别"""
+    message = DummyMessage()
+    state, _storage = make_state(message)
+
+    update_calls = []
+
+    async def fake_update_task(task_id: str, *, actor: str, **kwargs) -> TaskRecord:
+        update_calls.append((task_id, actor, kwargs.get("description")))
+        return _make_task(task_id=task_id, title="任务", status="research")
+
+    def monkeypatch_update():
+        import bot as bot_module
+        original_update = bot_module.TASK_SERVICE.update_task
+        bot_module.TASK_SERVICE.update_task = fake_update_task
+        return original_update
+
+    async def fake_render_task_detail(task_id: str):
+        return "任务详情", None
+
+    def monkeypatch_render():
+        import bot as bot_module
+        original_render = bot_module._render_task_detail
+        bot_module._render_task_detail = fake_render_task_detail
+        return original_render
+
+    async def scenario() -> str | None:
+        message.text = "1. ✅ 确认更新"  # 带序号和emoji的完整按钮文本
+        await state.update_data(
+            task_id="TASK_EDIT",
+            new_description="新的描述内容",
+            actor="Tester#1",
+            current_description="旧描述",
+        )
+        await state.set_state(bot.TaskDescriptionStates.waiting_confirm)
+
+        # 临时替换函数
+        original_update = monkeypatch_update()
+        original_render = monkeypatch_render()
+
+        try:
+            await bot.on_task_desc_confirm_stage_text(message, state)
+            return await state.get_state()
+        finally:
+            # 恢复原函数
+            bot.TASK_SERVICE.update_task = original_update
+            bot._render_task_detail = original_render
+
+    state_value = asyncio.run(scenario())
+
+    assert state_value is None, "确认后应清空状态"
+    assert update_calls == [("TASK_EDIT", "Tester#1", "新的描述内容")], "应调用更新任务"
+    assert message.calls and "任务描述已更新" in message.calls[0][0]
+
+
+def test_task_desc_confirm_text_input_still_works():
+    """测试直接输入文本（如"确认"、"取消"）仍然有效"""
+    message = DummyMessage()
+    state, _storage = make_state(message)
+
+    async def scenario() -> str | None:
+        message.text = "取消"  # 直接输入文本
+        await state.update_data(
+            task_id="TASK_EDIT",
+            new_description="草稿描述",
+            actor="Tester#1",
+            current_description="旧描述",
+        )
+        await state.set_state(bot.TaskDescriptionStates.waiting_confirm)
+        await bot.on_task_desc_confirm_stage_text(message, state)
+        return await state.get_state()
+
+    state_value = asyncio.run(scenario())
+
+    assert state_value is None, "取消后应清空状态"
+    assert message.calls and "已取消编辑任务描述" in message.calls[0][0]
+
+
+def test_task_desc_confirm_invalid_numeric_input():
+    """测试输入无效数字（如"0"、"99"）应提示重新选择"""
+    message = DummyMessage()
+    state, _storage = make_state(message)
+
+    async def scenario() -> str | None:
+        message.text = "99"  # 超出范围的数字
+        await state.update_data(
+            task_id="TASK_EDIT",
+            new_description="草稿描述",
+            actor="Tester#1",
+            current_description="旧描述",
+        )
+        await state.set_state(bot.TaskDescriptionStates.waiting_confirm)
+        await bot.on_task_desc_confirm_stage_text(message, state)
+        return await state.get_state()
+
+    state_value = asyncio.run(scenario())
+
+    # 应该保持在确认状态，并提示用户
+    assert state_value == bot.TaskDescriptionStates.waiting_confirm.state
+    assert message.calls
+    assert "当前处于确认阶段" in message.calls[0][0] or "请选择" in message.calls[0][0]
