@@ -419,8 +419,11 @@ def test_task_list_search_flow(monkeypatch):
         user_message = DummyMessage(text="登录")
         await bot.on_task_list_search_keyword(user_message, state)
         assert await state.get_state() is None
-        # 在 MarkdownV2 模式下 * 会被转义
-        assert message.edits and ("*任务搜索结果*" in message.edits[-1]["text"] or "\\*任务搜索结果\\*" in message.edits[-1]["text"])
+        # 在 MarkdownV2 模式下会出现 * 或 _ 的格式化占位
+        assert message.edits
+        header_text = message.edits[-1]["text"]
+        expected_headers = ("*任务搜索结果*", "\\*任务搜索结果\\*", "_任务搜索结果_")
+        assert any(header in header_text for header in expected_headers)
         assert "- 🛠️ 修复登录问题" not in message.edits[-1]["text"]
         assert "- ⚪ 修复登录问题" not in message.edits[-1]["text"]
         assert user_message.calls and "搜索完成" in user_message.calls[-1]["text"]
@@ -457,8 +460,11 @@ def test_task_list_search_cancel_restores_list(monkeypatch):
         cancel_message = DummyMessage(text="取消")
         await bot.on_task_list_search_keyword(cancel_message, state)
         assert await state.get_state() is None
-        # 在 MarkdownV2 模式下 * 会被转义
-        assert message.edits and ("*任务列表*" in message.edits[-1]["text"] or "\\*任务列表\\*" in message.edits[-1]["text"])
+        # 在 MarkdownV2 模式下会出现 * 或 _ 的格式化占位
+        assert message.edits
+        header_text = message.edits[-1]["text"]
+        expected_headers = ("*任务列表*", "\\*任务列表\\*", "_任务列表_")
+        assert any(header in header_text for header in expected_headers)
         assert cancel_message.calls and "已返回任务列表" in cancel_message.calls[-1]["text"]
 
     asyncio.run(_scenario())
